ClassificationMetric
====================

.. currentmodule:: pykeen.metrics

.. autoclass:: ClassificationMetric
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ClassificationMetric.get_description
      ~ClassificationMetric.score

   .. rubric:: Methods Documentation

   .. automethod:: get_description
   .. automethod:: score
